@@ -9,7 +9,7 @@
 # File:        $Source: /var/lib/cvs/ODO/lib/ODO.pm,v $
 # Created by:  Stephen Evanchik( <a href="mailto:evanchik@us.ibm.com">evanchik@us.ibm.com </a>)
 # Created on:  10/05/2004
-# Revision:	$Id: ODO.pm,v 1.4 2009-11-25 15:15:51 ubuntu Exp $
+# Revision:	$Id: ODO.pm,v 1.6 2010-02-16 15:51:06 ubuntu Exp $
 # 
 # Contributors:
 #     IBM Corporation - initial API and implementation
@@ -19,9 +19,9 @@ package ODO;
 use strict;
 use warnings;
 
-our $VERSION = '0.22';
+our $VERSION = '0.25';
 
-use base qw/Exporter Class::Base Class::Accessor Class::ParamParser/;
+use base qw/Exporter Class::Base Class::Accessor::Fast Class::ParamParser/;
 
 use Time::HiRes qw/gettimeofday tv_interval/;
 use Digest::MD5 qw/md5_hex/;
